@@ -970,7 +970,7 @@ def list_deps(config, ctx, module):
     data = {'modules': []}
     data['modules'] = sorted(map(
         lambda x: x.name, modules.get_module_flat_dependency_tree(module)))
-    data['modules'].append(module)
+    data['modules'].append(module.name)
 
     data['auto_install'] = sorted(map(
         lambda x: x.name, modules.get_filtered_auto_install_modules_based_on_module_list(
